==> xorg-server-1.8-20100305-i486-1sys.tgz: usr/doc/xorg-server-1.8-20100305/configure.sh <==
# Servers to build:

#MESA_VERSION=${MESA_VERSION:-7.6}


# For now, trying to compile with HAL/D-BUS leads to a compile failure
# with a ton of undefined symbols.  Until this is rectified, we will be
# leaving this feature off.  It's not terriby useful IMHO anyway --
# autodetection and configuration of input devices.

#CFLAGS="$SLKCFLAGS" \
#./autogen.sh \
./autogen.sh \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --infodir=/usr/info \
  --mandir=/usr/man \
  --enable-xcsecurity \
  --enable-shared --enable-static \
  --enable-glx-tls --enable-record --enable-tslib --disable-multibuffer \
  --enable-xf86bigfont \
  --enable-install-libxf86config --enable-aiglx --enable-dri --enable-dri2 --enable-xf86vidmode --enable-xcalibrate \
  --enable-dbe --enable-dpms \
  --enable-xfree86-utils --enable-xaa --enable-vgahw  --enable-vbe --enable-int10-module  --enable-dmx --enable-xvfb  --disable-xwin \
  --enable-xorg --enable-xnest --enable-kdrive  --enable-xephyr --enable-xfbdev \
  --with-pic \
  --with-int10=x86emu \
  --with-default-font-path="/usr/share/fonts/TTF,/usr/share/fonts/OTF,/usr/share/fonts/Type1,/usr/share/fonts/misc,/usr/share/fonts/75dpi/:unscaled" \
  --with-module-dir=/usr/lib/xorg/modules \
  --with-dri-driver-path=/usr/lib/xorg/modules/dri \
  --with-os-name="SYS 0.24" \
  --with-os-vendor="SYS" \
  --with-vendor-name="SYS" --with-vendor-web="ftp://guyane.dyn-o-saur.com/sys" \
  --with-xkb-path=/etc/X11/xkb \
  --with-xkb-output=/var/lib/xkb \
  --disable-config-dbus \
  --disable-config-hal \
  --build=i486-slackware-linux

# --with-mesa-source=/usr/local/src/mesa-${MESA_VERSION} \

==> xorg-server-1.9.0-i486-1sys.tgz: usr/doc/xorg-server-1.9.0/configure.sh <==
# Servers to build:

#MESA_VERSION=${MESA_VERSION:-7.6}


# For now, trying to compile with HAL/D-BUS leads to a compile failure
# with a ton of undefined symbols.  Until this is rectified, we will be
# leaving this feature off.  It's not terriby useful IMHO anyway --
# autodetection and configuration of input devices.

#CFLAGS="$SLKCFLAGS" \
#./autogen.sh \
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --infodir=/usr/info \
  --mandir=/usr/man \
  --enable-xcsecurity \
  --enable-shared --enable-static \
  --enable-glx-tls --enable-record --enable-tslib  \
  --enable-xf86bigfont \
  --enable-install-libxf86config --enable-aiglx --enable-dri --enable-dri2 --enable-xf86vidmode --enable-xcalibrate \
  --enable-dbe --enable-dpms \
  --enable-xfree86-utils --enable-xaa --enable-vgahw  --enable-vbe --enable-int10-module  --enable-dmx --enable-xvfb  --disable-xwin \
  --enable-xorg --enable-xnest --enable-kdrive  --enable-xephyr --enable-xfbdev \
  --with-pic \
  --with-int10=x86emu \
  --with-default-font-path="/usr/share/fonts/TTF,/usr/share/fonts/OTF,/usr/share/fonts/Type1,/usr/share/fonts/misc,/usr/share/fonts/75dpi/:unscaled" \
  --with-module-dir=/usr/lib/xorg/modules \
  --with-dri-driver-path=/usr/lib/xorg/modules/dri \
  --with-os-name="SYS 0.24" \
  --with-os-vendor="SYS" \
  --with-vendor-name="SYS" --with-vendor-web="ftp://guyane.dyn-o-saur.com/sys" \
  --with-xkb-path=/etc/X11/xkb \
  --with-xkb-output=/var/lib/xkb \
  --disable-config-dbus \
  --disable-config-hal \
  --build=i486-slackware-linux

# --with-mesa-source=/usr/local/src/mesa-${MESA_VERSION} \
#   --without-xmlto --without-fop \
